package eu.faircode.email;

/*
    This file is part of FairEmail.

    FairEmail is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    NetGuard is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with NetGuard.  If not, see <http://www.gnu.org/licenses/>.

    Copyright 2018 by Marcel Bokhorst (M66B)
*/

import android.content.SharedPreferences;
import android.os.Bundle;
import android.preference.PreferenceManager;
import android.text.method.LinkMovementMethod;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.CheckBox;
import android.widget.CompoundButton;
import android.widget.TextView;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

public class FragmentOptions extends FragmentEx {
    private CheckBox cbWebView;
    private TextView tvCustomTabs;
    private CheckBox cbSanitize;
    private CheckBox cbCompressImap;
    private CheckBox cbAvatars;
    private CheckBox cbDebug;

    @Override
    @Nullable
    public View onCreateView(@NonNull LayoutInflater inflater, @Nullable ViewGroup container, @Nullable Bundle savedInstanceState) {
        setSubtitle(R.string.title_advanced);

        View view = inflater.inflate(R.layout.fragment_options, container, false);

        // Get controls
        cbWebView = view.findViewById(R.id.cbWebView);
        tvCustomTabs = view.findViewById(R.id.tvCustomTabs);
        cbSanitize = view.findViewById(R.id.cbSanitize);
        cbCompressImap = view.findViewById(R.id.cbCompressImap);
        cbAvatars = view.findViewById(R.id.cbAvatars);
        cbDebug = view.findViewById(R.id.cbDebug);

        // Wire controls

        final SharedPreferences prefs = PreferenceManager.getDefaultSharedPreferences(getContext());

        cbWebView.setChecked(prefs.getBoolean("webview", false));
        cbWebView.setOnCheckedChangeListener(new CompoundButton.OnCheckedChangeListener() {
            @Override
            public void onCheckedChanged(CompoundButton compoundButton, boolean checked) {
                prefs.edit().putBoolean("webview", checked).apply();
            }
        });

        cbSanitize.setChecked(prefs.getBoolean("sanitize", false));
        cbSanitize.setOnCheckedChangeListener(new CompoundButton.OnCheckedChangeListener() {
            @Override
            public void onCheckedChanged(CompoundButton compoundButton, boolean checked) {
                prefs.edit().putBoolean("sanitize", checked).apply();
            }
        });

        cbCompressImap.setChecked(prefs.getBoolean("compress", true));
        cbCompressImap.setOnCheckedChangeListener(new CompoundButton.OnCheckedChangeListener() {
            @Override
            public void onCheckedChanged(CompoundButton compoundButton, boolean checked) {
                prefs.edit().putBoolean("compress", checked).apply();
            }
        });

        cbAvatars.setChecked(prefs.getBoolean("avatars", true));
        cbAvatars.setOnCheckedChangeListener(new CompoundButton.OnCheckedChangeListener() {
            @Override
            public void onCheckedChanged(CompoundButton compoundButton, boolean checked) {
                prefs.edit().putBoolean("avatars", checked).apply();
                if (!checked)
                    new Thread(new Runnable() {
                        @Override
                        public void run() {
                            Log.i(Helper.TAG, "Clearing avatars");
                            DB.getInstance(getContext()).message().clearMessageAvatars();
                        }
                    }).start();
            }
        });

        cbDebug.setChecked(prefs.getBoolean("debug", false));
        cbDebug.setOnCheckedChangeListener(new CompoundButton.OnCheckedChangeListener() {
            @Override
            public void onCheckedChanged(CompoundButton compoundButton, boolean checked) {
                prefs.edit().putBoolean("debug", checked).apply();
            }
        });

        tvCustomTabs.setMovementMethod(LinkMovementMethod.getInstance());

        return view;
    }
}
